@@ -5,15 +5,17 @@
 
 //! Server and client in async mode (alias r#async).
 
-pub mod client;
-pub mod server;
-pub mod stream;
+mod client;
+mod server;
+mod stream;
 #[macro_use]
-pub mod utils;
+#[doc(hidden)]
+mod utils;
+mod unix_incoming;
 
 #[doc(inline)]
 pub use crate::r#async::client::Client;
 #[doc(inline)]
 pub use crate::r#async::server::Server;
 #[doc(inline)]
-pub use crate::r#async::utils::{convert_response_to_buf, MethodHandler, TtrpcContext};
+pub use utils::{MethodHandler, TtrpcContext};
