@@ -25,6 +25,19 @@
 //! - `async`: Enables async server and client.
 //! - `sync`: Enables traditional sync server and client (default enabled).
 //! - `protobuf-codec`: Includes rust-protobuf (default enabled).
+//!
+//! # Socket address
+//!
+//! For Linux distributions, ttrpc-rust supports three types of socket:
+//!
+//! - `unix:///run/some.sock`: Normal Unix domain socket.
+//! - `unix://@/run/some.sock`: Abstract Unix domain socket.
+//! - `vsock://vsock://8:1024`: [vsock](https://man7.org/linux/man-pages/man7/vsock.7.html).
+//!
+//! For mscOS, ttrpc-rust **only** supports normal Unix domain socket:
+//!
+//! - `unix:///run/some.sock`: Normal Unix domain socket.
+//!
 
 #![cfg_attr(docsrs, feature(doc_cfg))]
 
@@ -34,15 +47,13 @@ extern crate log;
 #[macro_use]
 pub mod error;
 #[macro_use]
-pub mod common;
-#[allow(clippy::type_complexity, clippy::too_many_arguments)]
+mod common;
+#[allow(soft_unstable, clippy::type_complexity, clippy::too_many_arguments)]
 mod compiled {
     include!(concat!(env!("OUT_DIR"), "/mod.rs"));
 }
-#[doc(inline)]
-pub use compiled::ttrpc;
+pub use compiled::ttrpc as proto;
 
-#[doc(inline)]
 pub mod context;
 
 #[doc(inline)]
@@ -50,20 +61,21 @@ pub use crate::common::MessageHeader;
 #[doc(inline)]
 pub use crate::error::{get_status, Error, Result};
 #[doc(inline)]
-pub use crate::ttrpc::{Code, Request, Response, Status};
+pub use proto::{Code, Request, Response, Status};
 
 cfg_sync! {
     pub mod sync;
-    pub use crate::sync::channel::{write_message};
-    pub use crate::sync::utils::{response_to_channel, MethodHandler, TtrpcContext};
-    pub use crate::sync::client;
-    pub use crate::sync::client::Client;
-    pub use crate::sync::server;
-    pub use crate::sync::server::Server;
+    #[doc(hidden)]
+    pub use sync::response_to_channel;
+    #[doc(inline)]
+    pub use sync::{MethodHandler, TtrpcContext};
+    pub use sync::Client;
+    #[doc(inline)]
+    pub use sync::Server;
 }
 
 cfg_async! {
     pub mod asynchronous;
     #[doc(hidden)]
-    pub use crate::asynchronous as r#async;
+    pub use asynchronous as r#async;
 }
