@@ -27,8 +27,8 @@ use std::{io, thread};
 use crate::common::set_fd_close_exec;
 use crate::common::{client_connect, MESSAGE_TYPE_REQUEST, MESSAGE_TYPE_RESPONSE, SOCK_CLOEXEC};
 use crate::error::{Error, Result};
+use crate::proto::{Code, Request, Response};
 use crate::sync::channel::{read_message, write_message};
-use crate::ttrpc::{Code, Request, Response};
 use crate::MessageHeader;
 use std::time::Duration;
 
@@ -44,8 +44,8 @@ pub struct Client {
 }
 
 impl Client {
-    pub fn connect(path: &str) -> Result<Client> {
-        let fd = unsafe { client_connect(path)? };
+    pub fn connect(sockaddr: &str) -> Result<Client> {
+        let fd = unsafe { client_connect(sockaddr)? };
         Ok(Self::new(fd))
     }
 
@@ -225,16 +225,19 @@ impl Client {
             .send((buf, tx))
             .map_err(err_to_others_err!(e, "Send packet to sender error "))?;
 
-        let result = if req.timeout_nano == 0 {
-            rx.recv()
-                .map_err(err_to_others_err!(e, "Receive packet from recver error: "))?
+        let result: Result<Vec<u8>>;
+        if req.timeout_nano == 0 {
+            result = rx
+                .recv()
+                .map_err(err_to_others_err!(e, "Receive packet from recver error: "))?;
         } else {
-            rx.recv_timeout(Duration::from_nanos(req.timeout_nano as u64))
+            result = rx
+                .recv_timeout(Duration::from_nanos(req.timeout_nano as u64))
                 .map_err(err_to_others_err!(
                     e,
                     "Receive packet from recver timeout: "
-                ))?
-        };
+                ))?;
+        }
 
         let buf = result?;
         let mut s = CodedInputStream::from_bytes(&buf);
