@@ -25,15 +25,16 @@ use std::sync::{Arc, Mutex};
 use std::thread::JoinHandle;
 use std::{io, thread};
 
+use super::utils::response_to_channel;
 #[cfg(not(target_os = "linux"))]
 use crate::common::set_fd_close_exec;
 use crate::common::{self, MESSAGE_TYPE_REQUEST};
 use crate::context;
 use crate::error::{get_status, Error, Result};
+use crate::proto::{Code, Request, Response};
 use crate::sync::channel::{read_message, write_message};
-use crate::ttrpc::{Code, Request, Response};
 use crate::MessageHeader;
-use crate::{response_to_channel, MethodHandler, TtrpcContext};
+use crate::{MethodHandler, TtrpcContext};
 
 // poll_queue will create WAIT_THREAD_COUNT_DEFAULT threads in begin.
 // If wait thread count < WAIT_THREAD_COUNT_MIN, create number to WAIT_THREAD_COUNT_DEFAULT.
@@ -86,6 +87,7 @@ struct ThreadS<'a> {
     max: usize,
 }
 
+#[allow(clippy::too_many_arguments)]
 fn start_method_handler_thread(
     fd: RawFd,
     fdlock: Arc<Mutex<()>>,
@@ -186,8 +188,9 @@ fn start_method_handler_thread(
             trace!("Got Message request {:?}", req);
 
             let path = format!("/{}/{}", req.service, req.method);
-            let method = if let Some(x) = methods.get(&path) {
-                x
+            let method;
+            if let Some(x) = methods.get(&path) {
+                method = x;
             } else {
                 let status = get_status(Code::INVALID_ARGUMENT, format!("{} does not exist", path));
                 let mut res = Response::new();
@@ -204,7 +207,7 @@ fn start_method_handler_thread(
                     break;
                 }
                 continue;
-            };
+            }
             let ctx = TtrpcContext {
                 fd,
                 mh,
@@ -275,14 +278,14 @@ impl Server {
         Server::default()
     }
 
-    pub fn bind(mut self, host: &str) -> Result<Server> {
+    pub fn bind(mut self, sockaddr: &str) -> Result<Server> {
         if !self.listeners.is_empty() {
             return Err(Error::Others(
-                "ttrpc-rust just support 1 host now".to_string(),
+                "ttrpc-rust just support 1 sockaddr now".to_string(),
             ));
         }
 
-        let (fd, _) = common::do_bind(host)?;
+        let (fd, _) = common::do_bind(sockaddr)?;
         common::do_listen(fd)?;
 
         self.listeners.push(fd);
